@@ -1,3 +1,241 @@
+#' plot intensity of peaks across samples or samples across peaks
+#' @param data matrix
+#' @param lv factor vector for the column
+#' @param indexx index for matrix row
+#' @param indexy index for matrix column
+#' @param ... parameters for `title` function
+#' @return parallel coordinates plot
+#' @examples
+#' data(list)
+#' # selected peaks across samples
+#' plotpeak(t(list$data), lv = as.factor(c(rep(1,5),rep(2,nrow(list$data)-5))),1:10,1:10)
+#' # selected samples across peaks
+#' plotpeak(list$data, lv = as.factor(list$group$sample_group),1:10,1:10)
+#' @export
+plotpeak <- function(data,
+                     lv = NULL,
+                     indexx = NULL,
+                     indexy = NULL,
+                     ...) {
+        # from http://karolis.koncevicius.lt/posts/r_base_plotting_without_wrappers/
+        grDevices::palette(c("cornflowerblue", "red3", "orange"))
+        if (!is.null(indexx)) {
+                data <- data[indexx,]
+        }
+        if (!is.null(indexy)) {
+                data <- data[, indexy]
+                lv <- lv[indexy]
+        }
+        graphics::plot.new()
+        graphics::plot.window(xlim = c(1, nrow(data)), ylim = range(data))
+        graphics::grid(nx = NA, ny = NULL)
+        graphics::abline(
+                v = 1:nrow(data),
+                col = "grey",
+                lwd = 5,
+                lty = "dotted"
+        )
+        if (!is.null(lv)) {
+                graphics::matlines(data, col = lv, lty = 1)
+                graphics::legend(
+                        'top',
+                        inset = c(0, -.05),
+                        legend = unique(lv),
+                        col = unique(lv),
+                        lwd = 3,
+                        bty = 'n',
+                        horiz = T
+                )
+        } else{
+                graphics::matlines(
+                        data,
+                        col = grDevices::rgb(
+                                0,
+                                0,
+                                0,
+                                maxColorValue = 255,
+                                alpha = 100
+                        ),
+                        lty = 1
+                )
+        }
+        graphics::axis(2, lwd = 0, las = 2)
+        graphics::mtext(
+                stats::variable.names(t(data)),
+                3,
+                at = 1:nrow(data),
+                line = 1,
+                col = "darkgrey"
+        )
+}
+
+#' plot ridgeline density plot
+#' @param data matrix
+#' @param lv factor vector for the column
+#' @param indexx index for matrix row
+#' @param indexy index for matrix column
+#' @param ... parameters for `title` function
+#' @return ridgeline density plot
+#' @examples
+#' data(list)
+#' plotridge(t(list$data),indexy=c(1:10),xlab = 'Intensity',ylab = 'peaks')
+#' plotridge(log(list$data),as.factor(list$group$sample_group),xlab = 'Intensity',ylab = 'peaks')
+#' @export
+plotridge <- function(data,
+                      lv = NULL,
+                      indexx = NULL,
+                      indexy = NULL,
+                      ...) {
+        # from http://karolis.koncevicius.lt/posts/r_base_plotting_without_wrappers/
+        if (!is.null(indexx)) {
+                data <- data[indexx,]
+        }
+        if (!is.null(indexy)) {
+                data <- data[, indexy]
+                lv <- lv[indexy]
+        }
+        dens <- apply(data, 2, stats::density)
+        xs <- Map(getElement, dens, "x")
+        ys <- Map(getElement, dens, "y")
+        ys <- Map(function(x)
+                (x - min(x)) / max(x - min(x)) * 1.5, ys)
+        ys <- Map(`+`, ys, length(ys):1)
+
+        graphics::plot.new()
+        graphics::plot.window(xlim = range(xs), ylim = c(1, length(ys) +
+                                                                 1.5))
+        graphics::abline(h = length(ys):1, col = "grey")
+
+        if (!is.null(lv)) {
+                col <- grDevices::hcl.colors(nlevels(lv), "Zissou", alpha = 0.8)
+                Map(graphics::polygon,
+                    xs,
+                    ys,
+                    col = col[match(lv, unique(lv))])
+                graphics::legend(
+                        'topright',
+                        inset = c(0, -.05),
+                        legend = unique(lv),
+                        col = unique(lv),
+                        lwd = 3,
+                        bty = 'n',
+                        horiz = T
+                )
+        } else{
+                Map(
+                        graphics::polygon,
+                        xs,
+                        ys,
+                        col = grDevices::rgb(
+                                0,
+                                0,
+                                0,
+                                maxColorValue = 255,
+                                alpha = 100
+                        )
+                )
+        }
+
+        graphics::axis(1, tck = -0.01)
+        graphics::mtext(
+                names(dens),
+                2,
+                at = length(ys):1,
+                las = 2,
+                padj = 0
+        )
+        graphics::title(...)
+
+}
+
+#' plot 1-d density for multiple samples
+#' @param data matrix
+#' @param lv factor vector for the column
+#' @param indexx index for matrix row
+#' @param indexy index for matrix column
+#' @param ... parameters for `title` function
+#' @return NULL
+#' @examples
+#' data(list)
+#' plotrug(list$data)
+#' plotrug(log(list$data), lv = as.factor(list$group$sample_group))
+#' @export
+plotrug <- function(data,
+                    lv = NULL,
+                    indexx = NULL,
+                    indexy = NULL,
+                    ...) {
+        if (!is.null(indexx)) {
+                data <- data[indexx,]
+        }
+        if (!is.null(indexy)) {
+                data <- data[, indexy]
+                lv <- lv[indexy]
+        }
+
+        rugs <- apply(data, 2, function(x) x[order(x)])
+
+        rugs <- as.list(as.data.frame(rugs))
+        rugs <- lapply(rugs, function(x) x[is.finite(x)])
+
+        graphics::plot.new()
+        graphics::plot.window(xlim = range(rugs), ylim = c(1, length(rugs) +
+                                                                   1))
+
+
+        len <- Map(length, rugs)
+        idx <- 1:length(rugs)
+        yl <- Map(function(x, y)
+                rep(y - 0.3, x), len, idx)
+        yh <- Map(function(x, y)
+                rep(y + 0.3, x), len, idx)
+        if (!is.null(lv)) {
+                col <- grDevices::hcl.colors(nlevels(lv), "Zissou", alpha = 0.8)
+                Map(graphics::segments,
+                    rugs,
+                    yl,
+                    rugs,
+                    yh,
+                    col = col[match(lv, unique(lv))])
+                graphics::legend(
+                        'top',
+                        inset = c(0, -.05),
+                        legend = unique(lv),
+                        col = unique(lv),
+                        lwd = 3,
+                        bty = 'n',
+                        horiz = T
+
+                )
+        } else{
+                Map(
+                        graphics::segments,
+                        rugs,
+                        yl,
+                        rugs,
+                        yh,
+                        col = grDevices::rgb(
+                                0,
+                                0,
+                                0,
+                                maxColorValue = 255,
+                                alpha = 100
+                        )
+                )
+        }
+
+        graphics::axis(1, tck = -0.01)
+        graphics::mtext(
+                names(rugs),
+                2,
+                at = length(yl):1,
+                las = 2,
+                padj = 0
+        )
+        graphics::title(...)
+
+}
+
 #' plot the scatter plot for peaks list with threshold
 #' @param list list with data as peaks list, mz, rt and group information
 #' @param rt vector range of the retention time
@@ -24,7 +262,8 @@ plotmr <- function(list,
                        inscf = inscf,
                        imputation = imputation)
         lif <-
-                getfilter(list, rowindex = list$rsdindex & list$insindex)
+                getfilter(list, rowindex = list$rsdindex &
+                                  list$insindex)
         data <- lif$groupmean
         dataname <- colnames(data)
         mz <- lif$mz
@@ -68,7 +307,8 @@ plotmr <- function(list,
                                         y = mz[RT >
                                                        rt[1] &
                                                        RT < rt[2] &
-                                                       mz > ms[1] & mz <
+                                                       mz > ms[1] &
+                                                       mz <
                                                        ms[2]],
                                         cex = cex,
                                         col = col[i],
@@ -161,7 +401,7 @@ plotmr <- function(list,
                 }
                 graphics::legend(
                         "topright",
-                        legend = unique(list$group),
+                        legend = unique(list$group$sample_group),
                         col = col,
                         pch = 19,
                         horiz = T,
@@ -223,12 +463,13 @@ plotmrc <- function(list,
                 imputation = imputation,
         )
         lif <-
-                getfilter(list, rowindex = list$rsdindex & list$insindex)
+                getfilter(list, rowindex = list$rsdindex &
+                                  list$insindex)
         data <- lif$groupmean
         dataname <- colnames(data)
         mz <- lif$mz
         rt <- lif$rt
-        suppressWarnings(if (!is.na(data[1,1])) {
+        suppressWarnings(if (!is.na(data[1, 1])) {
                 diff1 <- data[, 1] - data[, 2]
                 diff2 <- data[, 2] - data[, 1]
                 diff1[diff1 < 0] <- 0
@@ -341,128 +582,110 @@ plotrsd <- function(list,
                        inscf = inscf,
                        imputation = imputation)
         lif <-
-                getfilter(list, rowindex = list$rsdindex & list$insindex)
+                getfilter(list, rowindex = list$rsdindex &
+                                  list$insindex)
         data <- lif$groupmean
         dataname <- colnames(data)
         mz <- lif$mz
         rt <- lif$rt
         rsd <- lif$grouprsd
 
-        n <- dim(rsd)[2]
-        col <- grDevices::rainbow(n, alpha = 0.318)
-
-        graphics::plot(
-                mz ~ rt,
-                xlab = "Retention Time(s)",
-                ylab = "m/z",
-                main = "RSD(%) distribution",
-                type = "n",
-                pch = 19,
-                ...
-        )
-
-        for (i in 1:n) {
-                cex = as.numeric(cut(rsd[, i], breaks = c(0, 20,
-                                                          40, 60, 80, Inf))) / 2
+        if (is.null(dim(rsd))) {
+                n <- 1
+                col <- grDevices::rainbow(1)
+                cex = as.numeric(cut(rsd, breaks = c(0, 20,
+                                                     40, 60, 80, Inf))) / 2
+                dataname <- unique(lif$group$sample_group)
+                graphics::plot(
+                        mz ~ rt,
+                        xlab = "Retention Time(s)",
+                        ylab = "m/z",
+                        main = "RSD(%) distribution",
+                        type = "n",
+                        pch = 19,
+                        ...
+                )
                 graphics::points(
                         x = rt,
                         y = mz,
                         ylim = ms,
                         cex = cex,
-                        col = col[i],
+                        col = col,
                         pch = 19
                 )
-        }
-        graphics::legend(
-                "topright",
-                legend = dataname,
-                col = col,
-                horiz = T,
-                pch = 19,
-                bty = "n",
-                inset = c(0,-0.25)
-        )
-        graphics::legend(
-                "topleft",
-                legend = cexlab,
-                pt.cex = c(1,
-                           2, 3, 4, 5) / 2,
-                pch = 19,
-                bty = "n",
-                horiz = T,
-                cex = 0.8,
-                col = grDevices::rgb(0, 0, 0, 0.318),
-                inset = c(0,-0.25)
-        )
-}
+                graphics::legend(
+                        "topright",
+                        legend = dataname,
+                        col = col,
+                        horiz = T,
+                        pch = 19,
+                        bty = "n",
+                        inset = c(0,-0.25)
+                )
+                graphics::legend(
+                        "topleft",
+                        legend = cexlab,
+                        pt.cex = c(1,
+                                   2, 3, 4, 5) / 2,
+                        pch = 19,
+                        bty = "n",
+                        horiz = T,
+                        cex = 0.8,
+                        col = grDevices::rgb(0, 0, 0, 0.318),
+                        inset = c(0,-0.25)
+                )
+        } else{
+                n <- dim(rsd)[2]
+                col <- grDevices::rainbow(n, alpha = 0.318)
+                graphics::plot(
+                        mz ~ rt,
+                        xlab = "Retention Time(s)",
+                        ylab = "m/z",
+                        main = "RSD(%) distribution",
+                        type = "n",
+                        pch = 19,
+                        ...
+                )
 
-#' plot scatter plot for rt-mz profile and output gif file for mutiple groups
-#' @param list list with data as peaks list, mz, rt and group information
-#' @param name file name for gif file, default test
-#' @param ms the mass range to plot the data
-#' @param inscf Log intensity cutoff for peaks across samples. If any peaks show a intensity higher than the cutoff in any samples, this peaks would not be filtered. default 5
-#' @param rsdcf the rsd cutoff of all peaks in all group
-#' @param imputation parameters for `getimputation` function method
-#' @param ... parameters for `plot` function
-#' @return gif file
-#' @examples
-#' \dontrun{
-#' data(list)
-#' gifmr(list)
-#' }
-#' @export
-gifmr <- function(list,
-                  ms = c(100, 500),
-                  rsdcf = 30,
-                  inscf = 5,
-                  imputation = "i",
-                  name = "test",
-                  ...) {
-        list <- getdoe(list,
-                       rsdcf = rsdcf,
-                       inscf = inscf,
-                       imputation = imputation)
-        lif <-
-                getfilter(list, rowindex = list$rsdindex & list$insindex)
-        data <- lif$groupmean
-        mz <- lif$mz
-        rt <- lif$rt
-        filename = paste0(name, ".gif")
-        mean <- apply(data, 1, mean)
-
-        graphics::plot(
-                mz ~ rt,
-                xlab = "Retention Time(s)",
-                ylab = "m/z",
-                pch = 19,
-                cex = log10(mean + 1) -
-                        4,
-                col = grDevices::rgb(0, 0, 1, 0.2),
-                main = "All peaks",
-                ...
-        )
-
-        col <- grDevices::rainbow(dim(data)[2], alpha = 0.318)
-        animation::saveGIF({
-                for (i in 1:dim(data)[2]) {
-                        name <- colnames(data)[i]
-                        value <- data[, i]
-                        graphics::plot(
-                                mz ~ rt,
-                                xlab = "Retention Time(s)",
-                                ylab = "m/z",
-                                pch = 19,
-                                cex = log10(value +
-                                                    1) - 4,
-                                col = col[i],
+                for (i in 1:n) {
+                        cex = as.numeric(cut(rsd[, i], breaks = c(
+                                0, 20,
+                                40, 60, 80, Inf
+                        ))) / 2
+                        graphics::points(
+                                x = rt,
+                                y = mz,
                                 ylim = ms,
-                                main = name,
-                                ...
+                                cex = cex,
+                                col = col[i],
+                                pch = 19
                         )
                 }
-        }, movie.name = filename, ani.width = 800, ani.height = 500)
+                graphics::legend(
+                        "topright",
+                        legend = dataname,
+                        col = col,
+                        horiz = T,
+                        pch = 19,
+                        bty = "n",
+                        inset = c(0,-0.25)
+                )
+                graphics::legend(
+                        "topleft",
+                        legend = cexlab,
+                        pt.cex = c(1,
+                                   2, 3, 4, 5) / 2,
+                        pch = 19,
+                        bty = "n",
+                        horiz = T,
+                        cex = 0.8,
+                        col = grDevices::rgb(0, 0, 0, 0.318),
+                        inset = c(0,-0.25)
+                )
+        }
 }
 
+
 #' plot the PCA for multiple samples
 #' @param data mzrt profile with row peaks and column samples
 #' @param lv group information
@@ -476,7 +699,7 @@ gifmr <- function(list,
 #' @return if xrange and yrange are not NULL, return file name of all selected samples on 2D score plot
 #' @examples
 #' data(list)
-#' plotpca(list$data, lv = as.character(list$group))
+#' plotpca(list$data, lv = as.character(list$group$sample_group))
 #' @export
 plotpca <- function(data,
                     lv = NULL,
@@ -500,7 +723,7 @@ plotpca <- function(data,
                 stats::prcomp(t(data), center = center, scale = scale)
         pcaoVars = signif(((pcao$sdev) ^ 2) / (sum((pcao$sdev) ^ 2)),
                           3) * 100
-        if(!is.null(pch)){
+        if (!is.null(pch)) {
                 graphics::plot(
                         pcao$x[, 1],
                         pcao$x[, 2],
@@ -512,7 +735,7 @@ plotpca <- function(data,
                         pch = pch,
                         ...
                 )
-        }else{
+        } else{
                 graphics::plot(
                         pcao$x[, 1],
                         pcao$x[, 2],
@@ -542,7 +765,7 @@ plotpca <- function(data,
 #' @return NULL
 #' @examples
 #' data(list)
-#' plothm(list$data, lv = as.factor(list$group))
+#' plothm(list$data, lv = as.factor(list$group$sample_group))
 #' @export
 plothm <- function(data, lv, index = NULL) {
         icolors <-
@@ -648,7 +871,7 @@ plothm <- function(data, lv, index = NULL) {
 #' @return NULL
 #' @examples
 #' data(list)
-#' plotden(list$data, lv = as.character(list$group),ylim = c(0,1))
+#' plotden(list$data, lv = as.character(list$group$sample_group),ylim = c(0,1))
 #' @export
 plotden <- function(data,
                     lv,
@@ -699,11 +922,11 @@ plotden <- function(data,
 #' @return Relative Log Abundance (RLA) plots
 #' @examples
 #' data(list)
-#' plotrla(list$data, as.factor(list$group))
+#' plotrla(list$data, as.factor(list$group$sample_group))
 #' @export
 plotrla <- function(data, lv, type = "g") {
         data <- log(data)
-        data[is.nan(data)] <- 0
+        data[is.nan(data)|is.infinite(data)] <- 0
         outmat = NULL
 
         if (type == "g") {
@@ -723,25 +946,32 @@ plotrla <- function(data, lv, type = "g") {
         graphics::boxplot(outmat, col = lv[order(lv)])
         graphics::abline(h = 0)
 }
-#' Relative Log Abundance Ridge (RLAR) plots
+
+#' Relative Log Abundance Ridge (RLAR) plots for samples or peaks
 #' @param data data as mzrt profile
-#' @param lv factor vector for the group infomation
+#' @param lv factor vector for the group infomation of samples
 #' @param type 'g' means group median based, other means all samples median based.
 #' @return Relative Log Abundance Ridge(RLA) plots
 #' @examples
 #' data(list)
-#' plotridges(list$data, as.factor(list$group))
+#' plotridges(list$data, as.factor(list$group$sample_group))
 #' @export
 plotridges <- function(data, lv, type = "g") {
         data <- log(data)
-        data[is.nan(data)] <- 0
+        data[is.nan(data)|is.infinite(data)] <- 0
         outmat = NULL
 
         if (type == "g") {
                 for (lvi in levels(lv)) {
                         submat <- data[, lv == lvi]
-                        median <- apply(submat, 1, median)
-                        tempmat <- sweep(submat, 1, median, "-")
+                        if(is.null(dim(submat))){
+                                tempmat <- submat
+
+                        }else{
+                                median <- apply(submat, 1, median)
+                                tempmat <- sweep(submat, 1, median, "-")
+                        }
+
                         outmat <- cbind(outmat, tempmat)
                 }
         } else {
@@ -749,19 +979,7 @@ plotridges <- function(data, lv, type = "g") {
                 outmat <- sweep(data, 1, median, "-")
 
         }
-
-        ov <- reshape2::melt(outmat)
-        colnames(outmat) <- lv[order(lv)]
-        ov2 <- reshape2::melt(outmat)
-        ov2$group <- as.factor(ov2$Var2)
-        ggplot2::ggplot(ov,
-                        ggplot2::aes(
-                                x = ov$value,
-                                y = ov$Var2,
-                                fill = ov2$group
-                        )) + ggridges::geom_density_ridges(stat = "binline",
-                                                           bins = 100) + ggplot2::xlim(-0.5, 0.5) + ggplot2::scale_fill_discrete(name = "Group") +
-                ggplot2::labs(x = "Relative Log Abundance", y = "Samples")
+        plotridge(outmat, lv, xlab = "Relative Log Abundance", ylab = 'Samples')
 }
 #' plot density weighted intensity for multiple samples
 #' @param list list with data as peaks list, mz, rt and group information
@@ -772,13 +990,110 @@ plotridges <- function(data, lv, type = "g") {
 #' data(list)
 #' plotdwtus(list)
 #' @export
-plotdwtus <- function(list,n=512,...){
-        dwtus <- apply(list$data, 2, function(x) getdwtus(x,n = n))
-        if(!is.null(list$order)){
-                graphics::plot(dwtus~as.numeric(list$order), xlab='Run order', ylab = 'DWTUS', col = as.numeric(as.factor(list$group)),...)
-                graphics::legend('topright',legend = unique(list$group),col = unique(as.numeric(as.factor(list$group))),pch = 19,bty = 'n')
-        }else{
-                graphics::plot(dwtus~as.numeric(as.factor(list$group)),xlab='Group', ylab = 'DWTUS',col = as.numeric(as.factor(list$group)),...)
-                graphics::legend('topright',legend = unique(list$group),col = unique(as.numeric(as.factor(list$group))),pch = 19,bty = 'n')
+plotdwtus <- function(list, n = 512, ...) {
+        dwtus <- apply(list$data, 2, function(x)
+                getdwtus(x, n = n))
+        if (!is.null(list$order)) {
+                graphics::plot(
+                        dwtus ~ as.numeric(list$order),
+                        xlab = 'Run order',
+                        ylab = 'DWTUS',
+                        col = as.numeric(as.factor(list$group$sample_group)),
+                        ...
+                )
+                graphics::legend(
+                        'topright',
+                        legend = unique(list$group$sample_group),
+                        col = unique(as.numeric(as.factor(
+                                list$group$sample_group
+                        ))),
+                        pch = 19,
+                        bty = 'n'
+                )
+        } else{
+                graphics::plot(
+                        dwtus ~ as.numeric(as.factor(list$group$sample_group)),
+                        xlab = 'Group',
+                        ylab = 'DWTUS',
+                        col = as.numeric(as.factor(list$group$sample_group)),
+                        ...
+                )
+                graphics::legend(
+                        'topright',
+                        legend = unique(list$group$sample_group),
+                        col = unique(as.numeric(as.factor(
+                                list$group$sample_group
+                        ))),
+                        pch = 19,
+                        bty = 'n'
+                )
         }
 }
+
+#' plot scatter plot for rt-mz profile and output gif file for mutiple groups
+#' @param list list with data as peaks list, mz, rt and group information
+#' @param name file name for gif file, default test
+#' @param ms the mass range to plot the data
+#' @param inscf Log intensity cutoff for peaks across samples. If any peaks show a intensity higher than the cutoff in any samples, this peaks would not be filtered. default 5
+#' @param rsdcf the rsd cutoff of all peaks in all group
+#' @param imputation parameters for `getimputation` function method
+#' @param ... parameters for `plot` function
+#' @return gif file
+#' @examples
+#' \dontrun{
+#' data(list)
+#' gifmr(list)
+#' }
+#' @export
+gifmr <- function(list,
+                  ms = c(100, 500),
+                  rsdcf = 30,
+                  inscf = 5,
+                  imputation = "i",
+                  name = "test",
+                  ...) {
+        list <- getdoe(list,
+                       rsdcf = rsdcf,
+                       inscf = inscf,
+                       imputation = imputation)
+        lif <-
+                getfilter(list, rowindex = list$rsdindex &
+                                  list$insindex)
+        data <- lif$groupmean
+        mz <- lif$mz
+        rt <- lif$rt
+        filename = paste0(name, ".gif")
+        mean <- apply(data, 1, mean)
+
+        graphics::plot(
+                mz ~ rt,
+                xlab = "Retention Time(s)",
+                ylab = "m/z",
+                pch = 19,
+                cex = log10(mean + 1) -
+                        4,
+                col = grDevices::rgb(0, 0, 1, 0.2),
+                main = "All peaks",
+                ...
+        )
+
+        col <- grDevices::rainbow(dim(data)[2], alpha = 0.318)
+        animation::saveGIF({
+                for (i in 1:dim(data)[2]) {
+                        name <- colnames(data)[i]
+                        value <- data[, i]
+                        graphics::plot(
+                                mz ~ rt,
+                                xlab = "Retention Time(s)",
+                                ylab = "m/z",
+                                pch = 19,
+                                cex = log10(value +
+                                                    1) - 4,
+                                col = col[i],
+                                ylim = ms,
+                                main = name,
+                                ...
+                        )
+                }
+        }, movie.name = filename, ani.width = 800, ani.height = 500)
+}
